@@ -1,3 +1,16 @@
+/**
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
+ *
+ * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ *
+ * @author Viktor Pracht <viktor.pracht@open-xchange.com>
+ */
+ 
 define('com.spamexperts/register', [
     'io.ox/core/extensions',
     'io.ox/core/upsell',
@@ -9,12 +22,12 @@ function (ext, upsell, gt, settings) {
 
     if (!upsell.visible('com.spamexperts')) return;
 
-    ext.point('io.ox/mail/folderview/sidepanel/links').extend({
+    ext.point('io.ox/core/foldertree/mail/app').extend({
         id: 'com.spamexperts',
-        index: 500,
+        index: 'last',
         draw: function () {
             if (_.device('!smartphone')) {
-                this.append($('<div>').append(
+                this.append($('<div class="links" style="margin-top: -1em">').append(
                     $('<a href="#" data-action="com.spamexperts" tabindex="1" role="button">')
                         .text(
                             //#. %1$s is the name of the configuration panel
